
Educational videos
==================

Tutorial videos
---------------

These videos were created for an older version of swyft; however, they may remain interesting to users. Check back and we will update them to the new version and expand them!

* `1 - Linear regression with swyft <https://www.loom.com/share/cefac9e4e84d482c89c5281b90121974>`_
* `2 - ConvNets, parameter regression and swyft <https://www.loom.com/share/1fc4785159bf4f0081e59693133a5ad3>`_
* ...more to come...

Academic videos
---------------

* `Truncated Marginal Neural Ratio Estimation <https://www.youtube.com/watch?v=euUxDdB5XY8>`_
